==> no_bloc_flutter-0.11.0.tar.gz: test/bloc_container_test.dart <==
import 'package:no_bloc_flutter/no_bloc_flutter.dart';
import 'package:flutter_test/flutter_test.dart';

class CounterBloc extends Bloc<int> {
  void increment() => setState(value + 1);

  void decrement() => setState(value - 1);
}

class CounterBloc2 extends Bloc<int> {
  void increment() => setState(value + 1);

  void decrement() => setState(value - 1);
}

void main() {
  setUp(() => BlocContainer.clear());

  test('container should fetch same bloc for same arg', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>(arg: 1);
    final bloc2 = BlocContainer.get<CounterBloc>(arg: 1);


    expect(bloc, bloc2);
  });

  test('container should fetch different blocs for different args', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>(arg: 1);
    final bloc2 = BlocContainer.get<CounterBloc>(arg: 2);

    expect(bloc, isNot(bloc2));
  });

  test('container should fetch same blocs if arg is null', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>();
    final bloc2 = BlocContainer.get<CounterBloc>();

    expect(bloc, bloc2);
  });

  test('container should fetch different blocs if useCache is false', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>();
    final bloc2 = BlocContainer.get<CounterBloc>();
    final bloc3 = BlocContainer.get<CounterBloc>(useCache: false);

    expect(bloc, bloc2);
    expect(bloc, isNot(bloc3));
  });

  test('container should fetch bloc of specified type even if args are same',
      () {
    BlocContainer.add((context, arg) => CounterBloc());
    BlocContainer.add((context, arg) => CounterBloc2());

    final bloc2 = BlocContainer.get<CounterBloc2>();

    expect(bloc2.runtimeType, isNot(CounterBloc));
  });
}

==> no_bloc_flutter-0.12.0.tar.gz: test/bloc_container_test.dart <==
import 'package:no_bloc_flutter/no_bloc_flutter.dart';
import 'package:flutter_test/flutter_test.dart';

class CounterBloc extends Bloc<int> {
  void increment() => setState(state + 1);

  void decrement() => setState(state - 1);
}

class CounterBloc2 extends Bloc<int> {
  void increment() => setState(state + 1);

  void decrement() => setState(state - 1);
}

void main() {
  setUp(() => BlocContainer.clear());

  test('container should fetch same bloc for same arg', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>(arg: 1);
    final bloc2 = BlocContainer.get<CounterBloc>(arg: 1);


    expect(bloc, bloc2);
  });

  test('container should fetch different blocs for different args', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>(arg: 1);
    final bloc2 = BlocContainer.get<CounterBloc>(arg: 2);

    expect(bloc, isNot(bloc2));
  });

  test('container should fetch same blocs if arg is null', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>();
    final bloc2 = BlocContainer.get<CounterBloc>();

    expect(bloc, bloc2);
  });

  test('container should fetch different blocs if useCache is false', () {
    BlocContainer.add<CounterBloc>((context, arg) => CounterBloc());

    final bloc = BlocContainer.get<CounterBloc>();
    final bloc2 = BlocContainer.get<CounterBloc>();
    final bloc3 = BlocContainer.get<CounterBloc>(useCache: false);

    expect(bloc, bloc2);
    expect(bloc, isNot(bloc3));
  });

  test('container should fetch bloc of specified type even if args are same',
      () {
    BlocContainer.add((context, arg) => CounterBloc());
    BlocContainer.add((context, arg) => CounterBloc2());

    final bloc2 = BlocContainer.get<CounterBloc2>();

    expect(bloc2.runtimeType, isNot(CounterBloc));
  });
}
